﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2014 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System.Drawing;
using HeuristicLab.Common;
using HeuristicLab.Core;
using HeuristicLab.Problems.DataAnalysis;

namespace HeuristicLab.DataPreprocessing {

  [Item("Feature Correlation Matrix", "Represents the feature correlation matrix.")]
  public class CorrelationMatrixContent : Item, IViewShortcut {

    public DataAnalysisProblemData ProblemData {
      get {
        var creator = new ProblemDataCreator(Context);
        return (DataAnalysisProblemData)creator.CreateProblemData();
      } 
    }

    public ITransactionalPreprocessingData PreprocessingData { 
      get {
        return Context.Data;
      } 
    }

    private IPreprocessingContext Context { get; set; }
    public CorrelationMatrixContent(IPreprocessingContext context) {
      Context = context;


    }

    public CorrelationMatrixContent(CorrelationMatrixContent original, Cloner cloner)
      : base(original, cloner) {

    }

    public static new Image StaticItemImage {
      get { return HeuristicLab.Common.Resources.VSImageLibrary.Gradient; }
    }

    public override IDeepCloneable Clone(Cloner cloner) {
      return new CorrelationMatrixContent(this, cloner);
    }

    public event DataPreprocessingChangedEventHandler Changed {
      add { PreprocessingData.Changed += value; }
      remove { PreprocessingData.Changed -= value; }
    }
  }
}
